@@ -82,8 +82,12 @@ escape_math = function(x) {
     if (length(z) == 0) return(z)
     paste0('`', z, '`')
   })
-  # if a line start or end with $$, treat it as math under some conditions
-  i = !grepl('^[$].+[$]$', x)
+  # now, if there are still lines starting and ending with $$, they might be
+  # math expressions of display style spanning multiple lines, e.g.,
+  # $$\alpha +
+  # \beta$$
+  # we assume that $$ can only appear once on one line
+  i = vapply(gregexpr('[$]', x), length, integer(1)) == 2
   if (any(i)) {
     x[i] = gsub('^([$][$])([^ ]+)', '`\\1\\2', x[i], perl = TRUE)
     x[i] = gsub('([^ ])([$][$])$', '\\1\\2`', x[i], perl = TRUE)
@@ -134,7 +138,7 @@ escape_math = function(x) {
 #' logo = file.path(R.home("doc"), "html", "logo.jpg")
 #' link = xfun::embed_file(logo, 'R-logo.jpg', 'Download R logo')
 #' link
-#' htmltools::browsable(link)
+#' if (interactive()) htmltools::browsable(link)
 embed_file = function(path, name = basename(path), text = paste('Download', name), ...) {
   h = paste0("data:", mime::guess_type(path), ";base64,", base64enc::base64encode(path))
   htmltools::a(text, href = h, download = name, ...)
