@@ -59,9 +59,14 @@
 #'   \code{tools::\link[tools]{package_dependencies}()} for possible values. The
 #'   special value \code{'hard'} means the hard dependencies, i.e.,
 #'   \code{c('Depends', 'Imports', 'LinkingTo')}.
-#' @param recheck Whether to only check the failed packages from last time. By
-#'   default, if there are any \file{*.Rcheck} directories, \code{recheck} will
-#'   be automatically set to \code{TRUE} if missing.
+#' @param recheck A vector of package names to be (re)checked. If not provided
+#'   and there are any \file{*.Rcheck} directories left by certain packages
+#'   (this often means these packages failed the last time), \code{recheck} will
+#'   be these packages; if there are no \file{*.Rcheck} directories but a text
+#'   file \file{recheck} exists, \code{recheck} will be the character vector
+#'   read from this file. This provides a way for you to manually specify the
+#'   packages to be checked. If there are no packages to be rechecked, all
+#'   reverse dependencies will be checked.
 #' @param ignore A vector of package names to be ignored in \command{R CMD
 #'   check}. If this argument is missing and a file \file{00ignore} exists, the
 #'   file will be read as a character vector and passed to this argument.
@@ -89,7 +94,7 @@
 #'   dependencies.
 #' @export
 rev_check = function(
-  pkg, which = 'all', recheck = FALSE, ignore = NULL, update = TRUE,
+  pkg, which = 'all', recheck = NULL, ignore = NULL, update = TRUE,
   src = file.path(src_dir, pkg), src_dir = getOption('xfun.rev_check.src_dir')
 ) {
   if (length(src) != 1 || !dir.exists(src)) stop(
@@ -102,11 +107,14 @@ rev_check = function(
   db = available.packages(type = 'source')
 
   unlink('*.Rcheck2', recursive = TRUE)
-  dirs = list.files('.', '.+[.]Rcheck$')
-  if (missing(recheck)) recheck = length(dirs) > 0
-  pkgs = if (recheck) {
-    gsub('.Rcheck$', '', dirs)
-  } else {
+  if (missing(recheck)) {
+    dirs = list.files('.', '.+[.]Rcheck$')
+    pkgs = gsub('.Rcheck$', '', dirs)
+    recheck = if (length(pkgs) == 0 && file.exists('recheck')) {
+      scan('recheck', 'character')
+    } else pkgs
+  }
+  pkgs = if (length(recheck)) recheck else {
     res = check_deps(pkg, db, which)
     pkgs_up = NULL
     if (update) {
@@ -362,8 +370,8 @@ compare_Rcheck = function(status_only = FALSE, output = '00check_diffs.md') {
     text = gsub('>', '+', gsub('^<', '-', res)),
     output = html_file <- with_ext(output, 'html'),
     header = c(
-      "<link href='https://cdn.bootcss.com/highlight.js/9.12.0/styles/github.min.css' rel='stylesheet' type='text/css' />",
-      "<script src='https://cdn.bootcss.com/highlight.js/9.12.0/highlight.min.js'></script>",
+      "<link href='https://cdn.jsdelivr.net/gh/highlightjs/cdn-release@9.17.1/build/styles/github.min.css' rel='stylesheet' type='text/css' />",
+      "<script src='https://cdn.jsdelivr.net/gh/highlightjs/cdn-release@9.17.1/build/highlight.min.js'></script>",
       "<script>hljs.initHighlightingOnLoad();</script>"
     ), encoding = 'UTF-8'
   )
@@ -410,14 +418,14 @@ cran_check_pages = function() {
   }
 }
 
-# kill a R CMD check process if it has been running for more then 60 minutes
+# kill a R CMD check process if it has been running for more then 30 minutes
 kill_long_processes = function(etime = 30) {
   while (TRUE) {
     if (length(pids <- list_long_processes(etime))) {
       message('Killing processes: ', paste(pids, collapse = ' '))
       system2('kill', pids)
     }
-    Sys.sleep(300)
+    Sys.sleep(30)
   }
 }
 
